betty.documentation module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.documentation module

Provide the Documentation API.

final class betty.documentation.DocumentationServer

  Bases: `Server`

  Serve the documentation site.

  __init__(cache_directory_path: Path, *, localizer: Localizer)
  property public_url: str

    The server’s public URL.

  async start() → None

    Start the server.

  async stop() → None

    Stop the server.